@@ -16,11 +16,11 @@ read handle
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.1.0
 
 =cut
 
-use version; our $VERSION = version->declare('v1.0.1');
+use version; our $VERSION = version->declare('v1.1.0');
 
 =head1 SYNOPSIS
 
@@ -50,6 +50,9 @@ other file handle.
     $bytecount = read($cfh, $buffer, 100);
     $bytecount = sysread($cfh, $buffer, 100);
 
+    # or single characters
+    $c = getc($cfh);
+
     close($cfh);
 
     # OO, too
@@ -57,6 +60,7 @@ other file handle.
     @lines = $cfh->getlines;
     $bytecount = $cfh->read($buffer, $size, $offset);
     $bytecount = $cfh->sysread($buffer, $size, $offset);
+    $c = $cfh->getc;
     $cfh->close;
     print "end!\n" if $cfh->eof;
 
@@ -183,7 +187,10 @@ sub READ {
   my $bufref = \$_[1];
   $offset //= 0;
 
-  return 0 if $self->EOF;
+  if ($self->EOF) {
+    $$bufref = '';
+    return 0;
+  }
 
   # $self->EOF has lined up the next source in $self->{ifh}
 
